==> kubernetes-model-1.0.4-sources.jar: io/fabric8/openshift/api/model/CustomDeploymentStrategyParamsFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.model.EnvVar;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.EnvVarFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.model.EnvVarBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class CustomDeploymentStrategyParamsFluent<T extends CustomDeploymentStrategyParamsFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     List<String> command = new ArrayList();     List<VisitableBuilder<EnvVar, ?>> environment = new ArrayList();     String image;     Map<String, Object> additionalProperties = new HashMap();

    public T addToCommand( String ...items){
    for (String item : items) {this.command.add(item);} return (T)this;
    }
    public List<String> getCommand(){
    return this.command;
    }
    public T withCommand( List<String> command){
    this.command.clear();if (command != null) {for (String item : command){this.addToCommand(item);}} return (T) this;
    }
    public T withCommand( String ...command){
    this.command.clear(); if (command != null) {for (String item :command){ this.addToCommand(item);}} return (T) this;
    }
    public T addToEnvironment( EnvVar ...items){
    for (EnvVar item : items) {EnvVarBuilder builder = new EnvVarBuilder(item);_visitables.add(builder);this.environment.add(builder);} return (T)this;
    }
    public List<EnvVar> getEnvironment(){
    return build(environment);
    }
    public T withEnvironment( List<EnvVar> environment){
    this.environment.clear();if (environment != null) {for (EnvVar item : environment){this.addToEnvironment(item);}} return (T) this;
    }
    public T withEnvironment( EnvVar ...environment){
    this.environment.clear(); if (environment != null) {for (EnvVar item :environment){ this.addToEnvironment(item);}} return (T) this;
    }
    public EnvironmentNested<T> addNewEnvironment(){
    return new EnvironmentNested<T>();
    }
    public EnvironmentNested<T> addNewEnvironmentLike( EnvVar item){
    return new EnvironmentNested<T>(item);
    }
    public String getImage(){
    return this.image;
    }
    public T withImage( String image){
    this.image=image; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class EnvironmentNested<N> extends EnvVarFluent<EnvironmentNested<N>> implements Nested<N>{

        private final EnvVarBuilder builder;
    
             EnvironmentNested ( EnvVar item){
        this.builder = new EnvVarBuilder(this, item);
        }
             EnvironmentNested (){
        this.builder = new EnvVarBuilder(this);
        }
    
            public N endEnvironment(){
            return and();
        }
            public N and(){
            return (N) CustomDeploymentStrategyParamsFluent.this.addToEnvironment(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.19-sources.jar: io/fabric8/openshift/api/model/CustomDeploymentStrategyParamsFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.EnvVarFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.EnvVarBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;

public class CustomDeploymentStrategyParamsFluent<T extends CustomDeploymentStrategyParamsFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     List<String> command = new ArrayList();     List<VisitableBuilder<EnvVar, ?>> environment = new ArrayList();     String image;     Map<String, Object> additionalProperties = new HashMap();

    public T addToCommand( String ...items){
    for (String item : items) {this.command.add(item);} return (T)this;
    }
    public T removeFromCommand( String ...items){
    for (String item : items) {this.command.remove(item);} return (T)this;
    }
    public List<String> getCommand(){
    return this.command;
    }
    public T withCommand( List<String> command){
    this.command.clear();if (command != null) {for (String item : command){this.addToCommand(item);}} return (T) this;
    }
    public T withCommand( String ...command){
    this.command.clear(); if (command != null) {for (String item :command){ this.addToCommand(item);}} return (T) this;
    }
    public T addToEnvironment( EnvVar ...items){
    for (EnvVar item : items) {EnvVarBuilder builder = new EnvVarBuilder(item);_visitables.add(builder);this.environment.add(builder);} return (T)this;
    }
    public T removeFromEnvironment( EnvVar ...items){
    for (EnvVar item : items) {EnvVarBuilder builder = new EnvVarBuilder(item);_visitables.remove(builder);this.environment.remove(builder);} return (T)this;
    }
    public List<EnvVar> getEnvironment(){
    return build(environment);
    }
    public T withEnvironment( List<EnvVar> environment){
    this.environment.clear();if (environment != null) {for (EnvVar item : environment){this.addToEnvironment(item);}} return (T) this;
    }
    public T withEnvironment( EnvVar ...environment){
    this.environment.clear(); if (environment != null) {for (EnvVar item :environment){ this.addToEnvironment(item);}} return (T) this;
    }
    public EnvironmentNested<T> addNewEnvironment(){
    return new EnvironmentNested<T>();
    }
    public EnvironmentNested<T> addNewEnvironmentLike( EnvVar item){
    return new EnvironmentNested<T>(item);
    }
    public String getImage(){
    return this.image;
    }
    public T withImage( String image){
    this.image=image; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
CustomDeploymentStrategyParamsFluent that = (CustomDeploymentStrategyParamsFluent) o;
if (command != null ? !command.equals(that.command) :that.command != null) return false;
if (environment != null ? !environment.equals(that.environment) :that.environment != null) return false;
if (image != null ? !image.equals(that.image) :that.image != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class EnvironmentNested<N> extends EnvVarFluent<EnvironmentNested<N>> implements Nested<N>{

        private final EnvVarBuilder builder;
    
             EnvironmentNested ( EnvVar item){
        this.builder = new EnvVarBuilder(this, item);
        }
             EnvironmentNested (){
        this.builder = new EnvVarBuilder(this);
        }
    
            public N endEnvironment(){
            return and();
        }
            public N and(){
            return (N) CustomDeploymentStrategyParamsFluent.this.addToEnvironment(builder.build());
        }
    
}


}
